import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(MaterialApp(
    title: 'Mobile Event Log',
    theme: ThemeData(
      primarySwatch: Colors.blue,
    ),
    initialRoute: '/',
    routes: {
      '/': (context) => Overview(),
      '/second': (context) => AddEvent(),
      '/third': (context) => ViewEvents(),
      '/forth': (context) => Configuration(),
    },
  ));
}

class Overview extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('Mobile Event Log')),
      body: Center(
          child: Column(
        mainAxisAlignment: MainAxisAlignment.spaceAround,
        children: <Widget>[
          ElevatedButton(
            child: const Text('Add Event'),
            onPressed: () {
              Navigator.pushNamed(context, '/second');
            },
          ),
          ElevatedButton(
            child: const Text('View Added Events'),
            onPressed: () {
              Navigator.pushNamed(context, '/third');
            },
          ),
          ElevatedButton(
            child: const Text('Configuration'),
            onPressed: () {
              Navigator.pushNamed(context, '/forth');
            },
          ),
        ],
      )),
    );
  }
}

class AddEvent extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Add Event"),
      ),
      body: Center(
        child: ElevatedButton(
          onPressed: () {
            Navigator.pop(context);
          },
          child: const Text('Back!'),
        ),
      ),
      bottomNavigationBar: Row(
        mainAxisAlignment: MainAxisAlignment.end,
        children: const [
          FloatingActionButton(
            heroTag: null,
            onPressed: null,
            tooltip: 'Add Event locally',
            child: Icon(Icons.add),
          )
        ],
      ),
    );
  }
}

class ViewEvents extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("View Added Events"),
      ),
      body: InteractiveViewer(
        minScale: 0.1,
        child: DataTable(
          columns: const <DataColumn>[
            DataColumn(
              label: Text(
                'URN',
                style: TextStyle(fontStyle: FontStyle.italic),
              ),
            ),
            DataColumn(
              label: Text(
                'Label',
                style: TextStyle(fontStyle: FontStyle.italic),
              ),
            ),
            DataColumn(
              label: Text(
                'Type',
                style: TextStyle(fontStyle: FontStyle.italic),
              ),
            ),
            DataColumn(
              label: Text(
                'Description',
                style: TextStyle(fontStyle: FontStyle.italic),
              ),
            ),
            DataColumn(
              label: Text(
                'Status',
                style: TextStyle(fontStyle: FontStyle.italic),
              ),
            ),
          ],
          rows: const <DataRow>[
            DataRow(
              cells: <DataCell>[
                DataCell(Text('station:neumayer_iii:awi_snow_sampler_1')),
                DataCell(Text('SML_KO21_SC01')),
                DataCell(Text('Deployment')),
                DataCell(Text('Remi tool Tag1 1 Traverse')),
                DataCell(Text('PENDING')),
              ],
            ),
            DataRow(
              cells: <DataCell>[
                DataCell(Text('radar_system:awi_pres_1')),
                DataCell(Text('MP_A_01+100m')),
                DataCell(Text('Information')),
                DataCell(Text('100 m NNW of MP_A_01 3 metal bars 2 m wide 20 cm apart 30 cm deep')),
                DataCell(Text('EXPORTED')),
              ],
            ),
            DataRow(
              cells: <DataCell>[
                DataCell(Text('radar_system:awi_pres_1')),
                DataCell(Text('MP_A_01')),
                DataCell(Text('Deployment')),
                DataCell(Text('position 2,35 m south of point midway TX RX')),
                DataCell(Text('EXPORTED')),
              ],
            ),
            DataRow(
              cells: <DataCell>[
                DataCell(Text('station:neumayer_iii:level_measure_1')),
                DataCell(Text('1')),
                DataCell(Text('Information')),
                DataCell(Text('Test measurements of snow deposition in cm follow')),
                DataCell(Text('PENDING')),
              ],
            ),
          ],
        ),
      ),
    );
  }
}

class Configuration extends StatefulWidget {
  @override
  State<Configuration> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<Configuration> {
  int _counter = 0;
  int _factor = 1;

  String selectedValue = '1';
  var available_items = [
    '1',
    '10',
    '100',
  ];

  late Future<String> eventTypes;

  @override
  void initState() {
    super.initState();
  }

  void _incrementCounter() {
    setState(() {
      _counter = _counter + _factor;
    });
  }

  void _decrementCounter() {
    setState(() {
      _counter = _counter - _factor;
    });
  }

  void _resetCounter() {
    setState(() {
      _counter = 0;
    });
  }

  void _getCollections() {
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Configuration'),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            const Text(
              'You have pushed the button this many times:',
            ),
            Text(
              '$_counter',
              style: Theme.of(context).textTheme.headline2,
            ),
            DropdownButton(
              value: selectedValue,
              icon: const Icon(Icons.keyboard_arrow_down),
              items: available_items.map((String available_items) {
                return DropdownMenuItem(
                  value: available_items,
                  child: Text(available_items),
                );
              }).toList(),
              onChanged: (String? newValue) {
                setState(() {
                  selectedValue = newValue!;
                  _factor = int.parse(selectedValue);
                });
              },
            ),
            Text('blabla'),
          ],
        ),
      ),
      bottomNavigationBar: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          FloatingActionButton(
            heroTag: null,
            onPressed: _incrementCounter,
            tooltip: 'Increment',
            child: const Icon(Icons.add),
          ),
          FloatingActionButton(
            heroTag: null,
            onPressed: _decrementCounter,
            tooltip: 'Decrement',
            child: const Text('-'),
          ),
          FloatingActionButton(
            heroTag: null,
            onPressed: _resetCounter,
            tooltip: 'Reset to 0',
            child: const Icon(Icons.delete),
          ),
          FloatingActionButton(
            heroTag: null,
            onPressed: _getCollections,
            tooltip: 'Reset to 0',
            child: const Text('Update'),
          ),
        ],
      ),
    );
  }
}
